mindroot.coreplugins.chat\_avatar package
=========================================

Module contents
---------------

.. automodule:: mindroot.coreplugins.chat_avatar
   :members:
   :show-inheritance:
   :undoc-members:
